#ifndef PREFIX_H
#define PREFIX_H

#include "native_common.h"
#undef DISABLE_SCUMM
#undef DISABLE_SCUMM_7_8
#undef DISABLE_HE

#endif
